@@ -32,15 +32,13 @@ namespace codes {
 bool GRIBDecoder::match(const eckit::message::Message& msg) const {
     size_t len    = msg.length();
     const char* p = static_cast<const char*>(msg.data());
-    return len >= 4
-           and ((p[0] == 'G' and p[1] == 'R' and p[2] == 'I' and p[3] == 'B')
-                or (p[0] == 'T' and p[1] == 'I' and p[2] == 'D' and p[3] == 'E')
-                or (p[0] == 'B' and p[1] == 'U' and p[2] == 'D' and p[3] == 'G'));
+    return len >= 4 and ((p[0] == 'G' and p[1] == 'R' and p[2] == 'I' and p[3] == 'B') or
+                         (p[0] == 'T' and p[1] == 'I' and p[2] == 'D' and p[3] == 'E') or
+                         (p[0] == 'B' and p[1] == 'U' and p[2] == 'D' and p[3] == 'G'));
 }
 
 
-void GRIBDecoder::getMetadata(const eckit::message::Message& msg,
-                              eckit::message::MetadataGatherer& gather,
+void GRIBDecoder::getMetadata(const eckit::message::Message& msg, eckit::message::MetadataGatherer& gather,
                               const eckit::message::GetMetadataOptions& options) const {
     static std::string gribToRequestNamespace = eckit::Resource<std::string>("gribToRequestNamespace", "mars");
     std::string nameSpace                     = options.nameSpace ? *options.nameSpace : gribToRequestNamespace;
