@@ -28,7 +28,9 @@ const LibEccodes& LibEccodes::instance() {
     return libeccodes;
 }
 
-const void* LibEccodes::addr() const { return (const void*)&codes_get_api_version; }
+const void* LibEccodes::addr() const {
+    return (const void*)&codes_get_api_version;
+}
 
 std::string LibEccodes::version() const {
     return ECCODES_VERSION_STR;
@@ -45,5 +47,4 @@ std::string LibEccodes::gitsha1(unsigned int count) const {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace metkit
-
+}  // namespace metkit
