@@ -14,15 +14,9 @@
 namespace metkit {
 namespace fields {
 
-SimpleFieldIndex::SimpleFieldIndex(eckit::Stream& s):
-    FieldIndex(s)
-{
-}
+SimpleFieldIndex::SimpleFieldIndex(eckit::Stream& s) : FieldIndex(s) {}
 
-SimpleFieldIndex::~SimpleFieldIndex()
-{
-}
-
-} // namespace fields
-} // namespace metkit
+SimpleFieldIndex::~SimpleFieldIndex() {}
 
+}  // namespace fields
+}  // namespace metkit
