@@ -17,9 +17,9 @@
 #ifndef metkit_MarsExpension_H
 #define metkit_MarsExpension_H
 
-#include "metkit/mars/MarsRequest.h"
 #include "eckit/memory/NonCopyable.h"
 #include "metkit/mars/MarsParsedRequest.h"
+#include "metkit/mars/MarsRequest.h"
 
 
 namespace metkit {
@@ -32,12 +32,14 @@ class MarsExpandContext;
 
 class FlattenCallback {
 public:
+
     virtual ~FlattenCallback();
     virtual void operator()(const MarsRequest&) = 0;
 };
 
 class ExpandCallback {
 public:
+
     virtual ~ExpandCallback();
     virtual void operator()(const MarsExpandContext&, const MarsRequest&) = 0;
 };
@@ -46,7 +48,8 @@ public:
 
 class MarsExpension : public eckit::NonCopyable {
 public:
-// -- Contructors
+
+    // -- Contructors
 
     MarsExpension(bool inherit, bool strict = false);
     ~MarsExpension();
@@ -56,17 +59,13 @@ public:
     MarsRequest expand(const MarsRequest&);
     std::vector<MarsRequest> expand(const std::vector<MarsParsedRequest>&);
 
-    void expand(const MarsExpandContext& ctx,
-                const MarsRequest& request,
-                ExpandCallback& cb);
+    void expand(const MarsExpandContext& ctx, const MarsRequest& request, ExpandCallback& cb);
 
 
-    void flatten(const MarsExpandContext& ctx,
-        const MarsRequest& request,
-                 FlattenCallback& callback);
+    void flatten(const MarsExpandContext& ctx, const MarsRequest& request, FlattenCallback& callback);
 
 
-private: // members
+private:  // members
 
     MarsLanguage& language(const MarsExpandContext&, const std::string& verb);
 
@@ -77,7 +76,7 @@ private: // members
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace mars
-} // namespace metkit
+}  // namespace mars
+}  // namespace metkit
 
 #endif
