@@ -33,8 +33,7 @@ class OdbMetadataDecoder : public odc::api::SpanVisitor {
 
 public:
 
-    OdbMetadataDecoder(eckit::message::MetadataGatherer& gatherer,
-                       const eckit::message::GetMetadataOptions& options,
+    OdbMetadataDecoder(eckit::message::MetadataGatherer& gatherer, const eckit::message::GetMetadataOptions& options,
                        const std::string& verb = "retrieve");
 
     virtual void operator()(const std::string& columnName, const std::set<long>& vals);
@@ -43,23 +42,22 @@ public:
 
     static const std::vector<std::string>& columnNames();
 
-private: // methods
+private:  // methods
 
     template <typename T>
     void visit(const std::string& columnName, const std::set<T>& vals, const metkit::mars::MarsLanguage& language);
 
-private: // members
+private:  // members
 
     metkit::mars::MarsLanguage language_;
     eckit::message::MetadataGatherer& gather_;
     eckit::message::GetMetadataOptions options_;
-
 };
 
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace codes
-} // namespace metkit
+}  // namespace codes
+}  // namespace metkit
 
 #endif
