@@ -9,15 +9,15 @@
  */
 
 
+#include "eckit/config/Resource.h"
+#include "eckit/exception/Exceptions.h"
 #include "eckit/io/FileHandle.h"
 #include "eckit/option/CmdArgs.h"
 #include "eckit/option/SimpleOption.h"
 #include "eckit/types/Date.h"
-#include "eckit/exception/Exceptions.h"
-#include "eckit/config/Resource.h"
 
-#include "eckit/message/Reader.h"
 #include "eckit/message/Message.h"
+#include "eckit/message/Reader.h"
 
 #include "metkit/codes/BUFRDecoder.h"
 #include "metkit/codes/BufrContent.h"
@@ -39,26 +39,24 @@ enum Status {
 class BufrCheck : public MetkitTool {
 public:
 
-    BufrCheck(int argc, char **argv) : MetkitTool(argc, argv) {
+    BufrCheck(int argc, char** argv) : MetkitTool(argc, argv) {
 
         options_.push_back(
             new SimpleOption<bool>("abort-on-error", "Abort in case of corrupted message, default = true"));
         options_.push_back(
             new SimpleOption<bool>("patch-on-error", "Try to patch corrupted messages, default = false"));
-        options_.push_back(
-            new SimpleOption<bool>("skip-on-error", "Skip corrupted messages, default = false"));
+        options_.push_back(new SimpleOption<bool>("skip-on-error", "Skip corrupted messages, default = false"));
+
+        options_.push_back(new SimpleOption<bool>(
+            "dont-patch-length", "Disable patching of message length in corrupted messages, default = false"));
+        options_.push_back(new SimpleOption<bool>(
+            "dont-patch-date", "Disable patching of date/time in corrupted messages, default = false"));
+        options_.push_back(new SimpleOption<bool>(
+            "ignore-century", "Disable patching of century in corrupted messages, default = false"));
+        options_.push_back(new SimpleOption<bool>("ignore-type", "Ignore inconsistent type/subtype, default = false"));
+        options_.push_back(new SimpleOption<long>("acceptable-time-discrepancy",
+                                                  "Acceptable time discrepancy in seconds, default = 300"));
 
-        options_.push_back(
-            new SimpleOption<bool>("dont-patch-length", "Disable patching of message length in corrupted messages, default = false"));
-        options_.push_back(
-            new SimpleOption<bool>("dont-patch-date", "Disable patching of date/time in corrupted messages, default = false"));
-        options_.push_back(
-            new SimpleOption<bool>("ignore-century", "Disable patching of century in corrupted messages, default = false"));
-        options_.push_back(
-            new SimpleOption<bool>("ignore-type", "Ignore inconsistent type/subtype, default = false"));
-        options_.push_back(
-            new SimpleOption<long>("acceptable-time-discrepancy", "Acceptable time discrepancy in seconds, default = 300"));
-           
         options_.push_back(
             new SimpleOption<bool>("verbose", "Print details of all corrupted messages, default = false"));
     }
@@ -66,6 +64,7 @@ public:
     virtual ~BufrCheck() {}
 
 private:  // methods
+
     int minimumPositionalArguments() const { return 2; }
 
     Status checkMessageLength(const message::Message& msg, int numMessage, eckit::StringDict& transformation);
@@ -81,6 +80,7 @@ private:  // methods
     virtual void usage(const std::string& tool) const;
 
 private:  // members
+
     bool verbose_;
     bool abort_;
     bool patch_;
@@ -101,24 +101,25 @@ void BufrCheck::execute(const CmdArgs& args) {
 void BufrCheck::init(const CmdArgs& args) {
 
     patch_ = args.getBool("patch-on-error", false);
-    skip_ = args.getBool("skip-on-error", false);
+    skip_  = args.getBool("skip-on-error", false);
     abort_ = args.getBool("abort-on-error", !(patch_ || skip_));
 
-    if (abort_ + patch_ + skip_>1) {
-        throw UserError("Inconsistent configuration. You can only specify one of [--abort-on-error, --patch-on-error, --skip-on-error]");
+    if (abort_ + patch_ + skip_ > 1) {
+        throw UserError(
+            "Inconsistent configuration. You can only specify one of [--abort-on-error, --patch-on-error, "
+            "--skip-on-error]");
     }
 
-    verbose_ = args.getBool("verbose", false);
-    ignoreLength_ = args.getBool("dont-patch-length", false);
-    ignoreDate_ = args.getBool("dont-patch-date", false);
+    verbose_       = args.getBool("verbose", false);
+    ignoreLength_  = args.getBool("dont-patch-length", false);
+    ignoreDate_    = args.getBool("dont-patch-date", false);
     ignoreCentury_ = args.getBool("ignore-century", false);
-    ignoreType_ = args.getBool("ignore-type", false);
+    ignoreType_    = args.getBool("ignore-type", false);
     timeThreshold_ = args.getLong("acceptable-time-discrepancy", 300);
 }
 
 void BufrCheck::usage(const std::string& tool) const {
-    Log::info() << "Usage: " << tool << " [options] [input] [output]" << std::endl
-                << std::endl;
+    Log::info() << "Usage: " << tool << " [options] [input] [output]" << std::endl << std::endl;
 
     Log::info() << "Examples:" << std::endl
                 << "=========" << std::endl
@@ -127,7 +128,8 @@ void BufrCheck::usage(const std::string& tool) const {
                 << std::endl
                 << tool << " --skip-on-error --verbose input.bufr output.bufr" << std::endl
                 << std::endl
-                << tool << " --patch-on-error --ignore-century --acceptable-time-discrepancy=600 input.bufr output.bufr" << std::endl
+                << tool << " --patch-on-error --ignore-century --acceptable-time-discrepancy=600 input.bufr output.bufr"
+                << std::endl
                 << std::endl
                 << tool << " --patch-on-error --dont-patch-date input.bufr output.bufr" << std::endl
                 << std::endl;
@@ -135,18 +137,18 @@ void BufrCheck::usage(const std::string& tool) const {
 
 Status BufrCheck::checkMessageLength(const message::Message& msg, int numMessage, eckit::StringDict& transformation) {
 
-    long totalLength = msg.getLong("totalLength");
+    long totalLength   = msg.getLong("totalLength");
     long messageLength = msg.getLong("messageLength");
 
     if (totalLength != messageLength && totalLength < WRONG_KEY_LENGTH) {
         if (verbose_) {
-            Log::error() << "message " << numMessage
-                << ", wrong key length in bufr message " << messageLength << " instead of " << totalLength
-                << std::endl;
+            Log::error() << "message " << numMessage << ", wrong key length in bufr message " << messageLength
+                         << " instead of " << totalLength << std::endl;
         }
         if (!patch_ || ignoreLength_) {
             return Status::CORRUPTED;
-        } else {
+        }
+        else {
             transformation.emplace("messageLength", std::to_string(totalLength));
             return Status::FIXED;
         }
@@ -156,26 +158,25 @@ Status BufrCheck::checkMessageLength(const message::Message& msg, int numMessage
 
 Status BufrCheck::checkSubType(const message::Message& msg, int numMessage) {
 
-    long type = msg.getLong("rdbType");
+    long type    = msg.getLong("rdbType");
     long subtype = msg.getLong("oldSubtype");
     long expectedType;
 
     if (codes::BUFRDecoder::typeBySubtype(subtype, expectedType)) {
         if (type == expectedType) {
             return Status::OK;
-        } else {
+        }
+        else {
             if (verbose_ || !ignoreType_) {
-                Log::error() << "message " << numMessage
-                    << ", type " << type << " and expected type " << expectedType << " don't match for subtype " << subtype
-                    << std::endl;
+                Log::error() << "message " << numMessage << ", type " << type << " and expected type " << expectedType
+                             << " don't match for subtype " << subtype << std::endl;
             }
             return Status::CORRUPTED;
         }
-    } else {
+    }
+    else {
         if (verbose_ || !ignoreType_) {
-            Log::error() << "message " << numMessage
-                << ", unknown subtype " << subtype
-                << std::endl;
+            Log::error() << "message " << numMessage << ", unknown subtype " << subtype << std::endl;
         }
         return Status::CORRUPTED;
     }
@@ -189,19 +190,19 @@ Status BufrCheck::checkDate(const message::Message& msg, int numMessage, eckit::
 
     long typicalYear = msg.getLong("typicalYear");
     if (ignoreCentury_) {
-        typicalYear = (localYear/100)*100 + typicalYear%100;
+        typicalYear = (localYear / 100) * 100 + typicalYear % 100;
     }
-    long typicalMonth = msg.getLong("typicalMonth");
-    long typicalDay = msg.getLong("typicalDay");
+    long typicalMonth  = msg.getLong("typicalMonth");
+    long typicalDay    = msg.getLong("typicalDay");
     long typicalJulian = 0;
     try {
         Date date(typicalYear, typicalMonth, typicalDay);
         typicalJulian = date.julian();
-    } catch(...) {
+    }
+    catch (...) {
         if (verbose_) {
-            Log::error() << "message " << numMessage
-                << ", date is weird " << typicalYear << "/" << typicalMonth << "/" << typicalDay
-                << std::endl;
+            Log::error() << "message " << numMessage << ", date is weird " << typicalYear << "/" << typicalMonth << "/"
+                         << typicalDay << std::endl;
         }
         if (!patch_) {
             return Status::CORRUPTED;
@@ -209,70 +210,69 @@ Status BufrCheck::checkDate(const message::Message& msg, int numMessage, eckit::
         toFix = !ignoreDate_;
     }
 
-    long typicalHour = msg.getLong("typicalHour");
+    long typicalHour   = msg.getLong("typicalHour");
     long typicalMinute = msg.getLong("typicalMinute");
     long typicalSecond = msg.getLong("typicalSecond");
 
-    if (typicalHour>23 || typicalHour<0 || typicalMinute>59 || typicalMinute<0 || typicalSecond>59 || typicalSecond<0) {
+    if (typicalHour > 23 || typicalHour < 0 || typicalMinute > 59 || typicalMinute < 0 || typicalSecond > 59 ||
+        typicalSecond < 0) {
         if (verbose_) {
-            Log::error() << "message " << numMessage
-                << ", typical time is weird " << typicalHour << ":" << typicalMinute << ":" << typicalSecond
-                << std::endl;
+            Log::error() << "message " << numMessage << ", typical time is weird " << typicalHour << ":"
+                         << typicalMinute << ":" << typicalSecond << std::endl;
         }
         if (!patch_) {
             return Status::CORRUPTED;
         }
         toFix = !ignoreDate_;
     }
-    long typicalTime = typicalHour*3600 + typicalMinute*60 + typicalSecond;
+    long typicalTime = typicalHour * 3600 + typicalMinute * 60 + typicalSecond;
 
 
-    long localMonth = msg.getLong("localMonth");
-    long localDay = msg.getLong("localDay");
+    long localMonth  = msg.getLong("localMonth");
+    long localDay    = msg.getLong("localDay");
     long localJulian = 0;
 
     try {
         Date date(localYear, localMonth, localDay);
         localJulian = date.julian();
-    } catch(...) {
+    }
+    catch (...) {
         if (verbose_) {
-            Log::error() << "message " << numMessage
-                << ", date is weird " << localYear << "/" << localMonth << "/" << localDay
-                << std::endl;
+            Log::error() << "message " << numMessage << ", date is weird " << localYear << "/" << localMonth << "/"
+                         << localDay << std::endl;
         }
         return Status::CORRUPTED;
     }
 
-    long localHour = msg.getLong("localHour");
+    long localHour   = msg.getLong("localHour");
     long localMinute = msg.getLong("localMinute");
     long localSecond = msg.getLong("localSecond");
 
     // we accept localSecond==60 for backward compatibility (filterbufr behaviour)
-    if (localHour>23 || localHour<0 || localMinute>59 || localMinute<0 || localSecond>60 || localSecond<0) {
+    if (localHour > 23 || localHour < 0 || localMinute > 59 || localMinute < 0 || localSecond > 60 || localSecond < 0) {
         if (verbose_) {
-            Log::error() << "message " << numMessage
-                << ", local time is weird " << localHour << ":" << localMinute << ":" << localSecond
-                << std::endl;
+            Log::error() << "message " << numMessage << ", local time is weird " << localHour << ":" << localMinute
+                         << ":" << localSecond << std::endl;
         }
         return Status::CORRUPTED;
     }
-    long localTime = localHour*3600 + localMinute*60 + localSecond;
+    long localTime = localHour * 3600 + localMinute * 60 + localSecond;
 
-    if (abs((typicalJulian-localJulian)*86400 + typicalTime-localTime)>timeThreshold_) {
+    if (abs((typicalJulian - localJulian) * 86400 + typicalTime - localTime) > timeThreshold_) {
         if (verbose_) {
-            Log::error() << "message " << numMessage << ", date-time (" <<
-            typicalYear << "/" << typicalMonth << "/" << typicalDay << " " << typicalHour << ":" << typicalMinute << ":" << typicalSecond << 
-            ") and local date-time (" <<
-            localYear << "/" << localMonth << "/" << localDay << " " << localHour << ":" << localMinute << ":" << localSecond << 
-            ") differs" << std::endl;
+            Log::error() << "message " << numMessage << ", date-time (" << typicalYear << "/" << typicalMonth << "/"
+                         << typicalDay << " " << typicalHour << ":" << typicalMinute << ":" << typicalSecond
+                         << ") and local date-time (" << localYear << "/" << localMonth << "/" << localDay << " "
+                         << localHour << ":" << localMinute << ":" << localSecond << ") differs" << std::endl;
         }
         toFix = !ignoreDate_;
     }
 
     if (toFix) {
         if (msg.getLong("edition") == 3) {
-            transformation.emplace("typicalYearOfCentury", std::to_string(localYear-2000));
-        } else {
+            transformation.emplace("typicalYearOfCentury", std::to_string(localYear - 2000));
+        }
+        else {
             transformation.emplace("typicalYear", std::to_string(localYear));
             transformation.emplace("typicalSecond", std::to_string(localSecond));
         }
@@ -292,16 +292,16 @@ void BufrCheck::process(const PathName& input, const PathName& output) {
     Offset pos;
     out.openForWrite(0);
     AutoClose closer(out);
-    
-    int err=0;
- 	void *buffer = NULL;
-	size_t size = 0;
+
+    int err      = 0;
+    void* buffer = NULL;
+    size_t size  = 0;
     bool ok;
-    unsigned int numMessage=0;
-    unsigned int missingKey=0;
-    unsigned int messageLength=0;
-    unsigned int inconsistentSubType=0;
-    unsigned int inconsistentDate=0;
+    unsigned int numMessage          = 0;
+    unsigned int missingKey          = 0;
+    unsigned int messageLength       = 0;
+    unsigned int inconsistentSubType = 0;
+    unsigned int inconsistentDate    = 0;
 
     message::Message rawMsg;
 
@@ -310,20 +310,22 @@ void BufrCheck::process(const PathName& input, const PathName& output) {
             pos = reader.position();
             if ((rawMsg = reader.next())) {
                 codes_handle* h = codes_handle_new_from_message(nullptr, rawMsg.data(), rawMsg.length());
-                if(!h) {
-                    throw FailedLibraryCall("eccodes", "codes_handle_new_from_message", "failed to create handle", Here());
+                if (!h) {
+                    throw FailedLibraryCall("eccodes", "codes_handle_new_from_message", "failed to create handle",
+                                            Here());
                 }
                 codes::BufrContent* c = new codes::BufrContent(h, true);
                 message::Message msg(c);
 
                 // verify the presence of section 2 (to store the MARS key)
                 long localSectionPresent = msg.getLong("localSectionPresent");
-                ok = localSectionPresent != 0;
+                ok                       = localSectionPresent != 0;
                 if (!ok) {
                     missingKey++;
-                } else {
+                }
+                else {
                     eckit::StringDict transformation;
-                    
+
                     switch (checkMessageLength(msg, numMessage, transformation)) {
                         case Status::CORRUPTED:
                             ok = false;
@@ -365,7 +367,8 @@ void BufrCheck::process(const PathName& input, const PathName& output) {
                     if (ok) {
                         if (transformation.size() == 0) {
                             msg.write(out);
-                        } else {
+                        }
+                        else {
                             eckit::message::Message m = msg.transform(transformation);
                             m.write(out);
                         }
@@ -376,32 +379,35 @@ void BufrCheck::process(const PathName& input, const PathName& output) {
                     Log::error() << "message " << numMessage << " not compliant" << std::endl;
                     exit(1);
                 }
-        
+
                 numMessage++;
             }
         }
-        catch(eckit::Exception& e) {
+        catch (eckit::Exception& e) {
             Log::warning() << " Error parsing message " << numMessage << " - offset " << pos << std::endl;
             if (verbose_) {
                 e.dumpStackTrace(Log::warning());
             }
         }
-    } while ( pos != reader.position() );
+    } while (pos != reader.position());
 
     if (missingKey)
-        Log::warning() << missingKey << " message" << (missingKey>1?"s miss ":" misses ") << " the MARS key" << std::endl;
+        Log::warning() << missingKey << " message" << (missingKey > 1 ? "s miss " : " misses ") << " the MARS key"
+                       << std::endl;
     if (messageLength)
-        Log::warning() << messageLength << " message" << (messageLength>1?"s ":" ") << " with incoherent message length in the MARS key" << std::endl;
+        Log::warning() << messageLength << " message" << (messageLength > 1 ? "s " : " ")
+                       << " with incoherent message length in the MARS key" << std::endl;
     if (inconsistentSubType)
-        Log::warning() << inconsistentSubType << " message" << (inconsistentSubType>1?"s ":" ") << " with unknown or inconsistent subtype" << std::endl;
+        Log::warning() << inconsistentSubType << " message" << (inconsistentSubType > 1 ? "s " : " ")
+                       << " with unknown or inconsistent subtype" << std::endl;
     if (inconsistentDate)
-        Log::warning() << inconsistentDate << " message" << (inconsistentDate>1? "s " : " ") << " with inconsistent date" << std::endl;
+        Log::warning() << inconsistentDate << " message" << (inconsistentDate > 1 ? "s " : " ")
+                       << " with inconsistent date" << std::endl;
 }
 
 //----------------------------------------------------------------------------------------------------------------------
 
-int main(int argc, char **argv)
-{
+int main(int argc, char** argv) {
     BufrCheck tool(argc, argv);
     return tool.start();
 }
